@@ -20,8 +20,7 @@
  */
 
 #include <unistd.h>
-#define NOMINMAX //don't want windows to collide with std::min
-#include <UnitTest++.h>
+#include <UnitTest++/UnitTest++.h>
 #include <stdio.h>
 #include <enchant.h>
 #include <enchant-provider.h>
@@ -161,9 +160,6 @@ TEST_FIXTURE(EnchantPwl_TestFixture,
 
   for(std::vector<std::string>::const_iterator itWord = sNewWords.begin(); itWord != sNewWords.end(); ++itWord){
     CHECK( IsWordInDictionary(*itWord) );
-    if(!IsWordInDictionary(*itWord)){
-         testResults_.OnTestFailure(UnitTest::TestDetails(m_details, __LINE__), itWord->c_str());
-    }
   }
 }
 
